<?php

declare(strict_types=1);

namespace Drupal\node_swapper\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Node swapper form.
 */
final class NodeSwapperForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'node_swapper_node_swapper';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    $form['src'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('Old Node'),
      '#description' => $this->t('Enter the name or ID of a node you want to decomission. <b>Note:</b> this node will <i>not</i> be destroyed.'),
      '#target_type' => 'node',
      '#required' => true
    ];

    $form['dest'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('New Node'),
      '#description' => $this->t('Enter the name or ID of the node you want to replace the old node with.'),
      '#target_type' => 'node',
      '#required' => true
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Submit & Review'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $args = [
      'src' => $form_state->getValue('src'),
      'dest' => $form_state->getValue('dest'),
    ];
    $form_state->setRedirect('node_swapper.node_swapper_confirm', $args);
  }
}
